@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '0.08';
+our $VERSION = '0.10';
 
 sub new {
 	my ($class) = @_;
@@ -1152,8 +1152,24 @@ Rajkumar Reddy
 
 =head1 COPYRIGHT AND LICENSE
 
+Rajkumar Reddy
+
+=head1 COPYRIGHT AND LICENSE
+
 Copyright (C) 2022 by Rajkumar Reddy. All rights reserved.
 
-Open Source.
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <https://www.gnu.org/licenses/>.
+
 
 =cut
